@@ -6,16 +6,6 @@ from FSEvents import *
 from PyObjCTools.TestSupport import *
 import os, time
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-except NameError:
-    long = int
-
 class TestFSEvents (TestCase):
 
     def testValues(self):
@@ -32,15 +22,40 @@ class TestFSEvents (TestCase):
             ('kFSEventStreamEventFlagRootChanged', 0x00000020),
             ('kFSEventStreamEventFlagMount', 0x00000040),
             ('kFSEventStreamEventFlagUnmount', 0x00000080),
+            ('kFSEventStreamCreateFlagIgnoreSelf', 0x00000008),
+            ('kFSEventStreamCreateFlagFileEvents', 0x00000010),
+            ('kFSEventStreamCreateFlagMarkSelf', 0x00000020),
+            ('kFSEventStreamCreateFlagUseExtendedData', 0x00000040),
+            ('kFSEventStreamEventFlagItemCreated', 0x00000100),
+            ('kFSEventStreamEventFlagItemRemoved', 0x00000200),
+            ('kFSEventStreamEventFlagItemInodeMetaMod', 0x00000400),
+            ('kFSEventStreamEventFlagItemRenamed', 0x00000800),
+            ('kFSEventStreamEventFlagItemModified', 0x00001000),
+            ('kFSEventStreamEventFlagItemFinderInfoMod', 0x00002000),
+            ('kFSEventStreamEventFlagItemChangeOwner', 0x00004000),
+            ('kFSEventStreamEventFlagItemXattrMod', 0x00008000),
+            ('kFSEventStreamEventFlagItemIsFile', 0x00010000),
+            ('kFSEventStreamEventFlagItemIsDir', 0x00020000),
+            ('kFSEventStreamEventFlagItemIsSymlink', 0x00040000),
+            ('kFSEventStreamEventFlagOwnEvent', 0x00080000),
+            ('kFSEventStreamEventFlagItemIsHardlink', 0x00100000),
+            ('kFSEventStreamEventFlagItemIsLastHardlink', 0x00200000),
+            ('kFSEventStreamEventFlagItemCloned', 0x00400000),
             ):
 
             self.assertHasAttr(FSEvents, k)
             self.assertIsInstance(getattr(FSEvents, k), (int, long))
-            self.assertEquals( getattr(FSEvents, k), v )
+            self.assertEqual( getattr(FSEvents, k), v )
 
         self.assertHasAttr(FSEvents, 'kFSEventStreamEventIdSinceNow')
         self.assertIsInstance(FSEvents.kFSEventStreamEventIdSinceNow, (int, long))
-        self.assertEquals(FSEvents.kFSEventStreamEventIdSinceNow, 18446744073709551615)
+        self.assertEqual(FSEvents.kFSEventStreamEventIdSinceNow, 18446744073709551615)
+
+        self.assertEqual(FSEvents.kFSEventStreamEventExtendedDataPathKey, "path")
+        self.assertIsInstance(FSEvents.kFSEventStreamEventExtendedDataPathKey, unicode)
+
+        self.assertEqual(FSEvents.kFSEventStreamEventExtendedFileIDKey, "fileID")
+        self.assertIsInstance(FSEvents.kFSEventStreamEventExtendedFileIDKey, unicode)
 
 
 
@@ -134,6 +149,15 @@ class TestFSEvents (TestCase):
         self.assertHasAttr(FSEvents, 'FSEventStreamRef')
         self.assertIsOpaquePointer(FSEventStreamRef)
 
+    @min_os_level('10.6')
+    def testFunctions10_6(self):
+        # Can't test beyond this because PyObjC doesn't support dispatch_queue_t yet
+        self.assertHasAttr(FSEvents, 'FSEventStreamSetDispatchQueue')
+
+    @min_os_level('10.9')
+    def testFunctions10_9(self):
+        self.assertResultIsBOOL(FSEvents.FSEventStreamSetExclusionPaths)
+
 
 if __name__ == "__main__":
     main()
